==> alibabacloud_vpc20160428-2.0.18.tar.gz: alibabacloud_vpc20160428-2.0.18/ChangeLog.md <==
2023-01-09 Version: 2.0.17
- Fix typos in ErrorCodes.
- Add ErrorMessage translation.
- Vpn support tag.
- Add attachment resource for terraform.
- Support diagnose vpn connection.
- Change timeout and api rate limit for fullnat.
- Add error Code.
- Add error code dependencyViolation vSwitchCidrReservation.
- Change input param.
- Add errorcode  IncorrectVpcStatus for action CreateVpnRouteEntry.
- Add errorcode FinancialLocked for action DeleteVpnConnection.
- Support resource group and tags.
- Support Return ResourceUid.

2022-12-22 Version: 2.0.16
- Supported set high definition monitor log status for eip.
- Supported batch associate eip to cloud products.

2022-12-22 Version: 2.0.15
- Support FlowLog Managed.
- Add error code for DeleteFullNatEntry, ListFullNatEntries, DescribeNatGateways.
- Change timeout for CreateFullNatEntry, DescribeNatGateways.
- Add error code.
- TagCode ExpressConnect.

2022-12-15 Version: 2.0.14
- Change DeleteFullNatEntry timeout.
- Add error code.
- Add error code for DeleteFullNatEntry.
- Fix error message.
- Fixed wrong char.

2022-12-09 Version: 2.0.13
- Add error code.
- Fix createVBR error message.
- Support vbrCrossCen grant.
- Fix bugs.
- Add new errorcode and error message in some API.
- Modify some error message in some error code.
- Modify parameter CustomerGatewayId in ModifyVpnAttachmentAttribute.

2022-11-21 Version: 2.0.12
- ResponseLog true.
- Support bandwidth.
- Fix error code translation error.
- Repair error code English translation.
- Changes the param NextToken of ListDhcpOptionsSet to optional in API docs.
- Fixed CreateVpcPrefixList paramer name invalid.

2022-11-14 Version: 2.0.11
- Supplementary error code mapping.
- Exposed unassociate ipv6 cidr param.
- Support Eip bind IpAddress.
- Supported query prefix list out add regionId.
- Support clearBgpAuthKey for ModifyBgpGroupAttribute.
- Add errorcode.
- CreateNatIpCidr natIpCidr must set.
- Fixed bugs for stsToken for DescribeEcGrantRelation.

2022-09-20 Version: 2.0.10
- DescribeSnatTableEntries DescribeSnatTableEntries ListFullnatEntries support query --by natGatewayId.

2022-09-01 Version: 2.0.9
- Support DescribeNatGateways return EipBindMode.

2022-08-31 Version: 2.0.8
- Support DescribeEipAddresses return Tags.

2022-08-26 Version: 2.0.7
- Support DescribeNatGateways return Tags.

2022-08-19 Version: 2.0.6
- Optimize DescribePublicIpAddress API.

2022-08-19 Version: 2.0.5
- Add DescribePublicIpAddress Interface.

2022-08-15 Version: 2.0.4
- Add param eipbindmode for api CreateNatGateway.

2022-08-02 Version: 2.0.3
- Supported latest apis.

2021-12-05 Version: 2.0.2
- Generated python 2016-04-28 for Vpc.

2021-12-02 Version: 2.0.1
- AMP Version Change.

2020-12-30 Version: 2.0.0
- AMP Version Change.

2020-09-02 Version: 1.0.1
- Generated python 2016-04-28 for Vpc.

==> alibabacloud_vpc20160428-2.0.21.tar.gz: alibabacloud_vpc20160428-2.0.21/ChangeLog.md <==
2023-01-31 Version: 2.0.20
- Supported set high definition monitor log status for eip.
- Supported batch associate eip to cloud products.
- Supported VpcDescribeVpcNatGatewayNetworkInterfaceQuota.

2023-01-31 Version: 2.0.19
- Supported set high definition monitor log status for eip.
- Supported batch associate eip to cloud products.
- Supported VpcDescribeVpcNatGatewayNetworkInterfaceQuota.

2023-01-16 Version: 2.0.18
- Supported set high definition monitor log status for eip.
- Supported batch associate eip to cloud products.
- Supported VpcDescribeVpcNatGatewayNetworkInterfaceQuota.

2023-01-09 Version: 2.0.17
- Fix typos in ErrorCodes.
- Add ErrorMessage translation.
- Vpn support tag.
- Add attachment resource for terraform.
- Support diagnose vpn connection.
- Change timeout and api rate limit for fullnat.
- Add error Code.
- Add error code dependencyViolation vSwitchCidrReservation.
- Change input param.
- Add errorcode  IncorrectVpcStatus for action CreateVpnRouteEntry.
- Add errorcode FinancialLocked for action DeleteVpnConnection.
- Support resource group and tags.
- Support Return ResourceUid.

2022-12-22 Version: 2.0.16
- Supported set high definition monitor log status for eip.
- Supported batch associate eip to cloud products.

2022-12-22 Version: 2.0.15
- Support FlowLog Managed.
- Add error code for DeleteFullNatEntry, ListFullNatEntries, DescribeNatGateways.
- Change timeout for CreateFullNatEntry, DescribeNatGateways.
- Add error code.
- TagCode ExpressConnect.

2022-12-15 Version: 2.0.14
- Change DeleteFullNatEntry timeout.
- Add error code.
- Add error code for DeleteFullNatEntry.
- Fix error message.
- Fixed wrong char.

2022-12-09 Version: 2.0.13
- Add error code.
- Fix createVBR error message.
- Support vbrCrossCen grant.
- Fix bugs.
- Add new errorcode and error message in some API.
- Modify some error message in some error code.
- Modify parameter CustomerGatewayId in ModifyVpnAttachmentAttribute.

2022-11-21 Version: 2.0.12
- ResponseLog true.
- Support bandwidth.
- Fix error code translation error.
- Repair error code English translation.
- Changes the param NextToken of ListDhcpOptionsSet to optional in API docs.
- Fixed CreateVpcPrefixList paramer name invalid.

2022-11-14 Version: 2.0.11
- Supplementary error code mapping.
- Exposed unassociate ipv6 cidr param.
- Support Eip bind IpAddress.
- Supported query prefix list out add regionId.
- Support clearBgpAuthKey for ModifyBgpGroupAttribute.
- Add errorcode.
- CreateNatIpCidr natIpCidr must set.
- Fixed bugs for stsToken for DescribeEcGrantRelation.

2022-09-20 Version: 2.0.10
- DescribeSnatTableEntries DescribeSnatTableEntries ListFullnatEntries support query --by natGatewayId.

2022-09-01 Version: 2.0.9
- Support DescribeNatGateways return EipBindMode.

2022-08-31 Version: 2.0.8
- Support DescribeEipAddresses return Tags.

2022-08-26 Version: 2.0.7
- Support DescribeNatGateways return Tags.

2022-08-19 Version: 2.0.6
- Optimize DescribePublicIpAddress API.

2022-08-19 Version: 2.0.5
- Add DescribePublicIpAddress Interface.

2022-08-15 Version: 2.0.4
- Add param eipbindmode for api CreateNatGateway.

2022-08-02 Version: 2.0.3
- Supported latest apis.

2021-12-05 Version: 2.0.2
- Generated python 2016-04-28 for Vpc.

2021-12-02 Version: 2.0.1
- AMP Version Change.

2020-12-30 Version: 2.0.0
- AMP Version Change.

2020-09-02 Version: 1.0.1
- Generated python 2016-04-28 for Vpc.
